@@ -1,8 +1,8 @@
 @muladd function perform_step!(integrator, cache::Kvaerno3ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31, α32 = cache.tab
+    (; γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31, α32) = cache.tab
     alg = unwrap_alg(integrator, true)
 
     # calculate W
@@ -64,10 +64,10 @@
 end
 
 @muladd function perform_step!(integrator, cache::Kvaerno3Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack z₁, z₂, z₃, z₄, atmp, nlsolver, step_limiter! = cache
-    @unpack tmp = nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31, α32 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; z₁, z₂, z₃, z₄, atmp, nlsolver, step_limiter!) = cache
+    (; tmp) = nlsolver
+    (; γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31, α32) = cache.tab
     alg = unwrap_alg(integrator, true)
 
     # precalculations
@@ -106,7 +106,7 @@ end
     if cache isa Kvaerno3Cache
         @.. broadcast=false z₄=a31 * z₁ + a32 * z₂ + γ * z₃ # use yhat as prediction
     elseif cache isa KenCarp3Cache
-        @unpack α41, α42 = cache.tab
+        (; α41, α42) = cache.tab
         @.. broadcast=false z₄=α41 * z₁ + α42 * z₂
     end
     nlsolver.z = z₄
@@ -143,11 +143,16 @@ end
 
 @muladd function perform_step!(integrator, cache::KenCarp3ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31, α32, ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4, ebtilde1, ebtilde2, ebtilde3, ebtilde4 = cache.tab
+    (; γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31, α32, ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4, ebtilde1, ebtilde2, ebtilde3, ebtilde4) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
+    k1 = nothing
+    k2 = nothing
+    k3 = nothing
+    k4 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -216,7 +221,7 @@ end
         integrator.stats.nf2 += 1
         tmp = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + ea41 * k1 + ea42 * k2 + ea43 * k3
     else
-        @unpack α41, α42 = cache.tab
+        (; α41, α42) = cache.tab
         z₄ = α41 * z₁ + α42 * z₂
         tmp = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃
     end
@@ -268,14 +273,15 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::KenCarp3Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack z₁, z₂, z₃, z₄, k1, k2, k3, k4, atmp, nlsolver, step_limiter! = cache
-    @unpack tmp = nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31, α32 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4 = cache.tab
-    @unpack ebtilde1, ebtilde2, ebtilde3, ebtilde4 = cache.tab
+    (; t, dt, uprev, u, p) = integrator
+    (; z₁, z₂, z₃, z₄, k1, k2, k3, k4, atmp, nlsolver, step_limiter!) = cache
+    (; tmp) = nlsolver
+    (; γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31, α32) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4) = cache.tab
+    (; ebtilde1, ebtilde2, ebtilde3, ebtilde4) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -348,7 +354,7 @@ end
         @.. broadcast=false tmp=uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + ea41 * k1 +
                                 ea42 * k2 + ea43 * k3
     else
-        @unpack α41, α42 = cache.tab
+        (; α41, α42) = cache.tab
         @.. broadcast=false z₄=α41 * z₁ + α42 * z₂
         @.. broadcast=false tmp=uprev + a41 * z₁ + a42 * z₂ + a43 * z₃
     end
@@ -404,11 +410,15 @@ end
 
 @muladd function perform_step!(integrator, cache::CFNLIRK3ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, c2, c3, ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4 = cache.tab
+    (; γ, a31, a32, a41, a42, a43, c2, c3, ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
+    k1 = nothing
+    k2 = nothing
+    k3 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -509,14 +519,15 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::CFNLIRK3Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack z₁, z₂, z₃, z₄, k1, k2, k3, k4, atmp, nlsolver = cache
-    @unpack tmp = nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, c2, c3 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4 = cache.tab
+    (; t, dt, uprev, u, p) = integrator
+    (; z₁, z₂, z₃, z₄, k1, k2, k3, k4, atmp, nlsolver) = cache
+    (; tmp) = nlsolver
+    (; γ, a31, a32, a41, a42, a43, c2, c3) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4) = cache.tab
 
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -613,11 +624,11 @@ end
 
 @muladd function perform_step!(integrator, cache::Kvaerno4ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, c3, c4 = cache.tab
-    @unpack α21, α31, α32, α41, α42 = cache.tab
-    @unpack btilde1, btilde2, btilde3, btilde4, btilde5 = cache.tab
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, c3, c4) = cache.tab
+    (; α21, α31, α32, α41, α42) = cache.tab
+    (; btilde1, btilde2, btilde3, btilde4, btilde5) = cache.tab
     alg = unwrap_alg(integrator, true)
 
     # precalculations
@@ -692,12 +703,12 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::Kvaerno4Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack z₁, z₂, z₃, z₄, z₅, atmp, nlsolver, step_limiter! = cache
-    @unpack tmp = nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, c3, c4 = cache.tab
-    @unpack α21, α31, α32, α41, α42 = cache.tab
-    @unpack btilde1, btilde2, btilde3, btilde4, btilde5 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; z₁, z₂, z₃, z₄, z₅, atmp, nlsolver, step_limiter!) = cache
+    (; tmp) = nlsolver
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, c3, c4) = cache.tab
+    (; α21, α31, α32, α41, α42) = cache.tab
+    (; btilde1, btilde2, btilde3, btilde4, btilde5) = cache.tab
     alg = unwrap_alg(integrator, true)
 
     # precalculations
@@ -782,16 +793,23 @@ end
 
 @muladd function perform_step!(integrator, cache::KenCarp4ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a63, a64, a65, c3, c4, c5 = cache.tab
-    @unpack α31, α32, α41, α42, α51, α52, α53, α54, α61, α62, α63, α64, α65 = cache.tab
-    @unpack btilde1, btilde3, btilde4, btilde5, btilde6 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65 = cache.tab
-    @unpack eb1, eb3, eb4, eb5, eb6 = cache.tab
-    @unpack ebtilde1, ebtilde3, ebtilde4, ebtilde5, ebtilde6 = cache.tab
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a63, a64, a65, c3, c4, c5) = cache.tab
+    (; α31, α32, α41, α42, α51, α52, α53, α54, α61, α62, α63, α64, α65) = cache.tab
+    (; btilde1, btilde3, btilde4, btilde5, btilde6) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65) = cache.tab
+    (; eb1, eb3, eb4, eb5, eb6) = cache.tab
+    (; ebtilde1, ebtilde3, ebtilde4, ebtilde5, ebtilde6) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
+    k1 = nothing
+    k2 = nothing
+    k3 = nothing
+    k4 = nothing
+    k5 = nothing
+    k6 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -954,18 +972,19 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::KenCarp4Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack z₁, z₂, z₃, z₄, z₅, z₆, atmp, nlsolver, step_limiter! = cache
-    @unpack tmp = nlsolver
-    @unpack k1, k2, k3, k4, k5, k6 = cache
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a63, a64, a65, c3, c4, c5 = cache.tab
-    @unpack α31, α32, α41, α42, α51, α52, α53, α54, α61, α62, α63, α64, α65 = cache.tab
-    @unpack btilde1, btilde3, btilde4, btilde5, btilde6 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65 = cache.tab
-    @unpack eb1, eb3, eb4, eb5, eb6 = cache.tab
-    @unpack ebtilde1, ebtilde3, ebtilde4, ebtilde5, ebtilde6 = cache.tab
+    (; t, dt, uprev, u, p) = integrator
+    (; z₁, z₂, z₃, z₄, z₅, z₆, atmp, nlsolver, step_limiter!) = cache
+    (; tmp) = nlsolver
+    (; k1, k2, k3, k4, k5, k6) = cache
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a63, a64, a65, c3, c4, c5) = cache.tab
+    (; α31, α32, α41, α42, α51, α52, α53, α54, α61, α62, α63, α64, α65) = cache.tab
+    (; btilde1, btilde3, btilde4, btilde5, btilde6) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65) = cache.tab
+    (; eb1, eb3, eb4, eb5, eb6) = cache.tab
+    (; ebtilde1, ebtilde3, ebtilde4, ebtilde5, ebtilde6) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -1137,11 +1156,11 @@ end
 
 @muladd function perform_step!(integrator, cache::Kvaerno5ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
+    (; t, dt, uprev, u, f, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, c3, c4, c5, c6 = cache.tab
-    @unpack btilde1, btilde3, btilde4, btilde5, btilde6, btilde7 = cache.tab
-    @unpack α31, α32, α41, α42, α43, α51, α52, α53, α61, α62, α63 = cache.tab
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, c3, c4, c5, c6) = cache.tab
+    (; btilde1, btilde3, btilde4, btilde5, btilde6, btilde7) = cache.tab
+    (; α31, α32, α41, α42, α43, α51, α52, α53, α61, α62, α63) = cache.tab
     alg = unwrap_alg(integrator, true)
 
     # precalculations
@@ -1235,12 +1254,12 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::Kvaerno5Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, f, p = integrator
-    @unpack z₁, z₂, z₃, z₄, z₅, z₆, z₇, atmp, nlsolver, step_limiter! = cache
-    @unpack tmp = nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, c3, c4, c5, c6 = cache.tab
-    @unpack btilde1, btilde3, btilde4, btilde5, btilde6, btilde7 = cache.tab
-    @unpack α31, α32, α41, α42, α43, α51, α52, α53, α61, α62, α63 = cache.tab
+    (; t, dt, uprev, u, f, p) = integrator
+    (; z₁, z₂, z₃, z₄, z₅, z₆, z₇, atmp, nlsolver, step_limiter!) = cache
+    (; tmp) = nlsolver
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, c3, c4, c5, c6) = cache.tab
+    (; btilde1, btilde3, btilde4, btilde5, btilde6, btilde7) = cache.tab
+    (; α31, α32, α41, α42, α43, α51, α52, α53, α61, α62, α63) = cache.tab
     alg = unwrap_alg(integrator, true)
 
     # precalculations
@@ -1344,17 +1363,26 @@ end
 
 @muladd function perform_step!(integrator, cache::KenCarp5ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a43, a51, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, a81, a84, a85, a86, a87, c3, c4, c5, c6, c7 = cache.tab
-    @unpack α31, α32, α41, α42, α51, α52, α61, α62, α71, α72, α73, α74, α75, α81, α82, α83, α84, α85 = cache.tab
-    @unpack btilde1, btilde4, btilde5, btilde6, btilde7, btilde8 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea43, ea51, ea53, ea54, ea61, ea63, ea64, ea65 = cache.tab
-    @unpack ea71, ea73, ea74, ea75, ea76, ea81, ea83, ea84, ea85, ea86, ea87 = cache.tab
-    @unpack eb1, eb4, eb5, eb6, eb7, eb8 = cache.tab
-    @unpack ebtilde1, ebtilde4, ebtilde5, ebtilde6, ebtilde7, ebtilde8 = cache.tab
+    (; γ, a31, a32, a41, a43, a51, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, a81, a84, a85, a86, a87, c3, c4, c5, c6, c7) = cache.tab
+    (; α31, α32, α41, α42, α51, α52, α61, α62, α71, α72, α73, α74, α75, α81, α82, α83, α84, α85) = cache.tab
+    (; btilde1, btilde4, btilde5, btilde6, btilde7, btilde8) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea43, ea51, ea53, ea54, ea61, ea63, ea64, ea65) = cache.tab
+    (; ea71, ea73, ea74, ea75, ea76, ea81, ea83, ea84, ea85, ea86, ea87) = cache.tab
+    (; eb1, eb4, eb5, eb6, eb7, eb8) = cache.tab
+    (; ebtilde1, ebtilde4, ebtilde5, ebtilde6, ebtilde7, ebtilde8) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
+    k1 = nothing
+    k2 = nothing
+    k3 = nothing
+    k4 = nothing
+    k5 = nothing
+    k6 = nothing
+    k7 = nothing
+    k8 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -1558,19 +1586,20 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::KenCarp5Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack z₁, z₂, z₃, z₄, z₅, z₆, z₇, z₈, atmp, nlsolver, step_limiter! = cache
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8 = cache
-    @unpack tmp = nlsolver
-    @unpack γ, a31, a32, a41, a43, a51, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, a81, a84, a85, a86, a87, c3, c4, c5, c6, c7 = cache.tab
-    @unpack α31, α32, α41, α42, α51, α52, α61, α62, α71, α72, α73, α74, α75, α81, α82, α83, α84, α85 = cache.tab
-    @unpack btilde1, btilde4, btilde5, btilde6, btilde7, btilde8 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea43, ea51, ea53, ea54, ea61, ea63, ea64, ea65 = cache.tab
-    @unpack ea71, ea73, ea74, ea75, ea76, ea81, ea83, ea84, ea85, ea86, ea87 = cache.tab
-    @unpack eb1, eb4, eb5, eb6, eb7, eb8 = cache.tab
-    @unpack ebtilde1, ebtilde4, ebtilde5, ebtilde6, ebtilde7, ebtilde8 = cache.tab
+    (; t, dt, uprev, u, p) = integrator
+    (; z₁, z₂, z₃, z₄, z₅, z₆, z₇, z₈, atmp, nlsolver, step_limiter!) = cache
+    (; k1, k2, k3, k4, k5, k6, k7, k8) = cache
+    (; tmp) = nlsolver
+    (; γ, a31, a32, a41, a43, a51, a53, a54, a61, a63, a64, a65, a71, a73, a74, a75, a76, a81, a84, a85, a86, a87, c3, c4, c5, c6, c7) = cache.tab
+    (; α31, α32, α41, α42, α51, α52, α61, α62, α71, α72, α73, α74, α75, α81, α82, α83, α84, α85) = cache.tab
+    (; btilde1, btilde4, btilde5, btilde6, btilde7, btilde8) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea43, ea51, ea53, ea54, ea61, ea63, ea64, ea65) = cache.tab
+    (; ea71, ea73, ea74, ea75, ea76, ea81, ea83, ea84, ea85, ea86, ea87) = cache.tab
+    (; eb1, eb4, eb5, eb6, eb7, eb8) = cache.tab
+    (; ebtilde1, ebtilde4, ebtilde5, ebtilde6, ebtilde7, ebtilde8) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -1783,16 +1812,24 @@ end
 
 @muladd function perform_step!(integrator, cache::KenCarp47ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, a65, a73, a74, a75, a76, c3, c4, c5, c6 = cache.tab
-    @unpack α31, α32, α41, α42, α43, α51, α52, α61, α62, α63, α71, α72, α73, α74, α75, α76 = cache.tab
-    @unpack btilde3, btilde4, btilde5, btilde6, btilde7 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65, ea71, ea72, ea73, ea74, ea75, ea76 = cache.tab
-    @unpack eb3, eb4, eb5, eb6, eb7 = cache.tab
-    @unpack ebtilde3, ebtilde4, ebtilde5, ebtilde6, ebtilde7 = cache.tab
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, a65, a73, a74, a75, a76, c3, c4, c5, c6) = cache.tab
+    (; α31, α32, α41, α42, α43, α51, α52, α61, α62, α63, α71, α72, α73, α74, α75, α76) = cache.tab
+    (; btilde3, btilde4, btilde5, btilde6, btilde7) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65, ea71, ea72, ea73, ea74, ea75, ea76) = cache.tab
+    (; eb3, eb4, eb5, eb6, eb7) = cache.tab
+    (; ebtilde3, ebtilde4, ebtilde5, ebtilde6, ebtilde7) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
+    k1 = nothing
+    k2 = nothing
+    k3 = nothing
+    k4 = nothing
+    k5 = nothing
+    k6 = nothing
+    k7 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -1975,18 +2012,19 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::KenCarp47Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack z₁, z₂, z₃, z₄, z₅, z₆, z₇, atmp, nlsolver = cache
-    @unpack k1, k2, k3, k4, k5, k6, k7 = cache
-    @unpack tmp = nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, a65, a73, a74, a75, a76, c3, c4, c5, c6 = cache.tab
-    @unpack α31, α32, α41, α42, α43, α51, α52, α61, α62, α63, α71, α72, α73, α74, α75, α76 = cache.tab
-    @unpack btilde3, btilde4, btilde5, btilde6, btilde7 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65, ea71, ea72, ea73, ea74, ea75, ea76 = cache.tab
-    @unpack eb3, eb4, eb5, eb6, eb7 = cache.tab
-    @unpack ebtilde3, ebtilde4, ebtilde5, ebtilde6, ebtilde7 = cache.tab
+    (; t, dt, uprev, u, p) = integrator
+    (; z₁, z₂, z₃, z₄, z₅, z₆, z₇, atmp, nlsolver) = cache
+    (; k1, k2, k3, k4, k5, k6, k7) = cache
+    (; tmp) = nlsolver
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, a65, a73, a74, a75, a76, c3, c4, c5, c6) = cache.tab
+    (; α31, α32, α41, α42, α43, α51, α52, α61, α62, α63, α71, α72, α73, α74, α75, α76) = cache.tab
+    (; btilde3, btilde4, btilde5, btilde6, btilde7) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65, ea71, ea72, ea73, ea74, ea75, ea76) = cache.tab
+    (; eb3, eb4, eb5, eb6, eb7) = cache.tab
+    (; ebtilde3, ebtilde4, ebtilde5, ebtilde6, ebtilde7) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -2179,17 +2217,26 @@ end
 
 @muladd function perform_step!(integrator, cache::KenCarp58ConstantCache,
         repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
+    (; t, dt, uprev, u, p) = integrator
     nlsolver = cache.nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, a65, a71, a72, a73, a74, a75, a76, a83, a84, a85, a86, a87, c3, c4, c5, c6, c7 = cache.tab
-    @unpack α31, α32, α41, α42, α51, α52, α61, α62, α63, α71, α72, α73, α81, α82, α83, α84, α85, α86, α87 = cache.tab
-    @unpack btilde3, btilde4, btilde5, btilde6, btilde7, btilde8 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65 = cache.tab
-    @unpack ea71, ea72, ea73, ea74, ea75, ea76, ea81, ea82, ea83, ea84, ea85, ea86, ea87 = cache.tab
-    @unpack eb3, eb4, eb5, eb6, eb7, eb8 = cache.tab
-    @unpack ebtilde3, ebtilde4, ebtilde5, ebtilde6, ebtilde7, ebtilde8 = cache.tab
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, a65, a71, a72, a73, a74, a75, a76, a83, a84, a85, a86, a87, c3, c4, c5, c6, c7) = cache.tab
+    (; α31, α32, α41, α42, α51, α52, α61, α62, α63, α71, α72, α73, α81, α82, α83, α84, α85, α86, α87) = cache.tab
+    (; btilde3, btilde4, btilde5, btilde6, btilde7, btilde8) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65) = cache.tab
+    (; ea71, ea72, ea73, ea74, ea75, ea76, ea81, ea82, ea83, ea84, ea85, ea86, ea87) = cache.tab
+    (; eb3, eb4, eb5, eb6, eb7, eb8) = cache.tab
+    (; ebtilde3, ebtilde4, ebtilde5, ebtilde6, ebtilde7, ebtilde8) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
+    k1 = nothing
+    k2 = nothing
+    k3 = nothing
+    k4 = nothing
+    k5 = nothing
+    k6 = nothing
+    k7 = nothing
+    k8 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
@@ -2395,19 +2442,20 @@ end
 end
 
 @muladd function perform_step!(integrator, cache::KenCarp58Cache, repeat_step = false)
-    @unpack t, dt, uprev, u, p = integrator
-    @unpack z₁, z₂, z₃, z₄, z₅, z₆, z₇, z₈, atmp, nlsolver = cache
-    @unpack k1, k2, k3, k4, k5, k6, k7, k8 = cache
-    @unpack tmp = nlsolver
-    @unpack γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, a65, a71, a72, a73, a74, a75, a76, a83, a84, a85, a86, a87, c3, c4, c5, c6, c7 = cache.tab
-    @unpack α31, α32, α41, α42, α51, α52, α61, α62, α63, α71, α72, α73, α81, α82, α83, α84, α85, α86, α87 = cache.tab
-    @unpack btilde3, btilde4, btilde5, btilde6, btilde7, btilde8 = cache.tab
-    @unpack ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65 = cache.tab
-    @unpack ea71, ea72, ea73, ea74, ea75, ea76, ea81, ea82, ea83, ea84, ea85, ea86, ea87 = cache.tab
-    @unpack eb3, eb4, eb5, eb6, eb7, eb8 = cache.tab
-    @unpack ebtilde3, ebtilde4, ebtilde5, ebtilde6, ebtilde7, ebtilde8 = cache.tab
+    (; t, dt, uprev, u, p) = integrator
+    (; z₁, z₂, z₃, z₄, z₅, z₆, z₇, z₈, atmp, nlsolver) = cache
+    (; k1, k2, k3, k4, k5, k6, k7, k8) = cache
+    (; tmp) = nlsolver
+    (; γ, a31, a32, a41, a42, a43, a51, a52, a53, a54, a61, a62, a63, a64, a65, a71, a72, a73, a74, a75, a76, a83, a84, a85, a86, a87, c3, c4, c5, c6, c7) = cache.tab
+    (; α31, α32, α41, α42, α51, α52, α61, α62, α63, α71, α72, α73, α81, α82, α83, α84, α85, α86, α87) = cache.tab
+    (; btilde3, btilde4, btilde5, btilde6, btilde7, btilde8) = cache.tab
+    (; ea21, ea31, ea32, ea41, ea42, ea43, ea51, ea52, ea53, ea54, ea61, ea62, ea63, ea64, ea65) = cache.tab
+    (; ea71, ea72, ea73, ea74, ea75, ea76, ea81, ea82, ea83, ea84, ea85, ea86, ea87) = cache.tab
+    (; eb3, eb4, eb5, eb6, eb7, eb8) = cache.tab
+    (; ebtilde3, ebtilde4, ebtilde5, ebtilde6, ebtilde7, ebtilde8) = cache.tab
     alg = unwrap_alg(integrator, true)
 
+    f2 = nothing
     if integrator.f isa SplitFunction
         f = integrator.f.f1
         f2 = integrator.f.f2
